==> webkit2gtk_2.45.3.orig.tar.xz: webkitgtk-2.45.3/Source/WebKit/UIProcess/API/glib/WebKitNotificationProvider.h <==
/*
 * Copyright (C) 2013 Igalia S.L.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#pragma once

#include "NotificationService.h"
#include "WebKitNotification.h"
#include "WebKitWebContext.h"
#include <wtf/Forward.h>
#include <wtf/HashMap.h>
#include <wtf/glib/GRefPtr.h>
#include <wtf/text/StringHash.h>

namespace WebCore {
class NotificationResources;
}

namespace WebKit {
class WebNotificationManagerProxy;
class WebNotification;
class WebPageProxy;

class WebKitNotificationProvider final : public NotificationService::Observer {
    WTF_MAKE_FAST_ALLOCATED;
public:
    WebKitNotificationProvider(WebNotificationManagerProxy*, WebKitWebContext*);
    ~WebKitNotificationProvider();

    void show(WebPageProxy*, WebNotification&, RefPtr<WebCore::NotificationResources>&&);
    void cancel(const WebNotification&);
    void clearNotifications(const Vector<WebNotificationIdentifier>&);

    HashMap<WTF::String, bool> notificationPermissions();
    void setNotificationPermissions(HashMap<String, bool>&&);

private:
    void cancelNotificationByID(WebNotificationIdentifier);
    static void apiNotificationCloseCallback(WebKitNotification*, WebKitNotificationProvider*);
    static void apiNotificationClickedCallback(WebKitNotification*, WebKitNotificationProvider*);
    static void apiNotificationWeakNotify(gpointer, GObject*);
    void addAPINotification(WebKitNotification*);
    void removeAPINotification(WebKitNotification*);
    void removeAPINotification(WebNotificationIdentifier);
    void closeAPINotification(WebNotificationIdentifier);

    void withdrawAnyPreviousAPINotificationMatchingTag(const CString&);

    void show(WebNotification&, const RefPtr<WebCore::NotificationResources>&);

    // NotificationService
    void didClickNotification(WebNotificationIdentifier) final;
    void didCloseNotification(WebNotificationIdentifier) final;

    WebKitWebContext* m_webContext;
    HashMap<WTF::String, bool> m_notificationPermissions;
    RefPtr<WebNotificationManagerProxy> m_notificationManager;
    HashMap<WebNotificationIdentifier, GRefPtr<WebKitNotification>> m_apiNotifications;
    bool m_observerRegistered { false };
};

} // namespace WebKit

==> webkit2gtk_2.50.5.orig.tar.xz: webkitgtk-2.50.5/Source/WebKit/UIProcess/API/glib/WebKitNotificationProvider.h <==
/*
 * Copyright (C) 2013 Igalia S.L.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#pragma once

#include "NotificationService.h"
#include "WebKitNotification.h"
#include "WebKitWebContext.h"
#include <wtf/Forward.h>
#include <wtf/HashMap.h>
#include <wtf/TZoneMalloc.h>
#include <wtf/glib/GRefPtr.h>
#include <wtf/text/StringHash.h>

namespace WebCore {
class NotificationResources;
}

namespace WebKit {
class WebNotificationManagerProxy;
class WebNotification;
class WebPageProxy;

class WebKitNotificationProvider final : public NotificationService::Observer {
    WTF_MAKE_TZONE_ALLOCATED(WebKitNotificationProvider);
public:
    WebKitNotificationProvider(WebNotificationManagerProxy*, WebKitWebContext*);
    ~WebKitNotificationProvider();

    void show(WebPageProxy*, WebNotification&, RefPtr<WebCore::NotificationResources>&&);
    void cancel(const WebNotification&);
    void clearNotifications(const Vector<WebNotificationIdentifier>&);

    HashMap<WTF::String, bool> notificationPermissions();
    void setNotificationPermissions(HashMap<String, bool>&&);

private:
    void cancelNotificationByID(WebNotificationIdentifier);
    static void apiNotificationCloseCallback(WebKitNotification*, WebKitNotificationProvider*);
    static void apiNotificationClickedCallback(WebKitNotification*, WebKitNotificationProvider*);
    static void apiNotificationWeakNotify(gpointer, GObject*);
    void addAPINotification(WebKitNotification*);
    void removeAPINotification(WebKitNotification*);
    void removeAPINotification(WebNotificationIdentifier);
    void closeAPINotification(WebNotificationIdentifier);

    void withdrawAnyPreviousAPINotificationMatchingTag(const CString&);

    void show(WebNotification&, const RefPtr<WebCore::NotificationResources>&);

    // NotificationService
    void didClickNotification(WebNotificationIdentifier) final;
    void didCloseNotification(WebNotificationIdentifier) final;

    WebKitWebContext* m_webContext;
    HashMap<WTF::String, bool> m_notificationPermissions;
    RefPtr<WebNotificationManagerProxy> m_notificationManager;
    HashMap<WebNotificationIdentifier, GRefPtr<WebKitNotification>> m_apiNotifications;
    bool m_observerRegistered { false };
};

} // namespace WebKit
